'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true
});

var _stream = require('stream');

var _child_process = require('child_process');

var slice = Array.prototype.slice;

exports['default'] = CliWrapper;

function CliWrapper(command) {
  if (!(this instanceof CliWrapper)) {
    return new CliWrapper(command);
  }
  this.command = command;
}

CliWrapper.prototype = {
  call: function call() {
    var _this = this;

    var args = slice.call(arguments);
    return new Promise(function (resolve, reject) {
      var parts = [_this.command].concat(args);
      var command = parts.join(' ');

      (0, _child_process.exec)(command, function (err, stdout, stderr) {
        if (err) {
          err = new Error(err.message + '\n' + stderr);
          return reject(err);
        }
        resolve(stdout);
      });
    });
  },

  scall: function scall() {
    var args = slice.call(arguments);
    var cmd = (0, _child_process.spawn)(this.command, args);
    var errout = '';
    var stream = new _stream.PassThrough();

    cmd.stderr.on('data', function (data) {
      errout += data;
    });

    cmd.stdout.on('data', function (data) {
      stream.write(data);
    });

    cmd.on('close', function (code) {
      if (code !== 0) {
        stream.emit('error', new Error(errout));
      } else {
        stream.end();
      }
    });

    return stream;
  }
};
module.exports = exports['default'];
